@@ -3,8 +3,8 @@ use wasm_bindgen_test::wasm_bindgen_test;
 #[test]
 #[wasm_bindgen_test]
 fn verify_validation() {
-    use lunesrs::account::signatures::{fast_signature, validate_signature};
-    use lunesrs::account::wallet::{to_private_key, to_public_key};
+    use lunesrs::wallet::signatures::{fast_signature, validate_signature};
+    use lunesrs::wallet::assembly::{to_private_key, to_public_key};
 
     let prvk = to_private_key(vec![1; 32]);
     let pubk = to_public_key(prvk.clone());
